export const visualEditorFunctionTemplate = `import { withNetlifySDKContext } from "@netlify/sdk/ui/functions";

export default withNetlifySDKContext(async (req, context) => {
  const { client, teamId } = context;

  const query = new URL(req.url).searchParams;
  const siteId = query.get("siteId");
  const configurationId = query.get("configurationId");
  const projectId = query.get("projectId") as string;

  try {
    if (!teamId || !siteId) {
      return Response.json({}, { status: 400 });
    }
    if (req.method === "GET") {
      if (!configurationId) {
        return Response.json({});
      }
      const config = await client.getVisualEditorConfiguration({
        teamId,
        siteId,
        configurationId,
      });
      if (!config) {
        return Response.json({});
      }
      return Response.json({
        name: config.name,
        prefix: config.prefix,
        config: config.config,
      });
    } else if (req.method === "PUT") {
      const body = (await req.json()) as {
        name: string;
        prefix: string;
        config: Record<string, any>;
        projectId: string;
      };
      const { name, prefix, config } = body;
      if (configurationId && configurationId !== "") {
        await client.updateVisualEditorConfiguration({
          teamId,
          siteId,
          configurationId,
          name,
          prefix,
          config,
          projectId,
        });
      } else {
        await client.createVisualEditorConfiguration({
          teamId,
          siteId,
          name,
          prefix,
          config,
          projectId,
        });
      }
      return Response.json({}, { status: 202 });
    } else {
      return Response.json({}, { status: 405 });
    }
  } catch (_e) {
    return Response.json({}, { status: 500 });
  }
});
`;
//# sourceMappingURL=visual-editor.ts.template.js.map