export const connectFunctionTemplate = `import { withNetlifySDKContext } from "@netlify/sdk/ui/functions";

export default withNetlifySDKContext(async (req, context) => {
  const { client, teamId } = context;

  const query = new URL(req.url).searchParams;
  const dataLayerId = query.get("dataLayerId");
  const configurationId = query.get("configurationId");

  try {
    if (!teamId || !dataLayerId) {
      return Response.json({}, { status: 400 });
    }
    if (req.method === "GET") {
      if (!configurationId) {
        return Response.json({});
      }
      const config = await client.getConnectConfiguration({
        teamId,
        dataLayerId,
        configurationId,
      });
      if (!config) {
        return Response.json({});
      }
      return Response.json({
        name: config.name,
        prefix: config.prefix,
        config: config.config,
      });
    } else if (req.method === "PUT") {
      const body = (await req.json()) as {
        name: string;
        prefix: string;
        config: Record<string, any>;
      };
      const { name, prefix, config } = body;
      if (configurationId && configurationId !== "") {
        await client.updateConnectConfiguration({
          teamId,
          dataLayerId,
          configurationId,
          name,
          prefix,
          config,
        });
      } else {
        await client.createConnectConfiguration({
          teamId,
          dataLayerId,
          name,
          prefix,
          config,
        });
      }
      return Response.json({}, { status: 202 });
    } else {
      return Response.json({}, { status: 405 });
    }
  } catch (_e) {
    return Response.json({}, { status: 500 });
  }
});
`;
